pitchtools.ObjectVector
=======================

.. abjad-lineage:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector

.. autoclass:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.clear
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.get
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.has_key
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.items
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.iteritems
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.iterkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.itervalues
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.keys
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.pop
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.popitem
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.setdefault
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.update
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.values
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewitems
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewvalues
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__setitem__
   :noindex:
